==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/EditorDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditorDefinitionDescription } from "./EditorDefinitionDescription";
/**
 * @hidden
 */
var EditorDefinitionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(EditorDefinitionDescriptionMetadata, _super);
    function EditorDefinitionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EditorDefinitionDescriptionMetadata.b = function (a) {
        if (EditorDefinitionDescriptionMetadata.a == null) {
            EditorDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            EditorDefinitionDescriptionMetadata.c(EditorDefinitionDescriptionMetadata.a);
        }
        if (a.j(EditorDefinitionDescriptionMetadata.a)) {
            return;
        }
        a.y(EditorDefinitionDescriptionMetadata.a);
    };
    EditorDefinitionDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    EditorDefinitionDescriptionMetadata.d = function (a) {
        EditorDefinitionDescriptionMetadata.b(a);
        a.aa("EditorDefinition", function () { return new EditorDefinitionDescription(); });
        a.z("EditorDefinition", EditorDefinitionDescriptionMetadata.a);
    };
    EditorDefinitionDescriptionMetadata.$t = markType(EditorDefinitionDescriptionMetadata, 'EditorDefinitionDescriptionMetadata');
    EditorDefinitionDescriptionMetadata.a = null;
    return EditorDefinitionDescriptionMetadata;
}(Base));
export { EditorDefinitionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/EditorDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditorDefinitionDescription } from "./EditorDefinitionDescription";
/**
 * @hidden
 */
var EditorDefinitionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(EditorDefinitionDescriptionMetadata, _super);
    function EditorDefinitionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EditorDefinitionDescriptionMetadata.b = function (a) {
        if (EditorDefinitionDescriptionMetadata.a == null) {
            EditorDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            EditorDefinitionDescriptionMetadata.c(EditorDefinitionDescriptionMetadata.a);
        }
        if (a.k(EditorDefinitionDescriptionMetadata.a)) {
            return;
        }
        a.aa(EditorDefinitionDescriptionMetadata.a);
    };
    EditorDefinitionDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
    };
    EditorDefinitionDescriptionMetadata.d = function (a) {
        EditorDefinitionDescriptionMetadata.b(a);
        a.ac("EditorDefinition", function () { return new EditorDefinitionDescription(); });
        a.ab("EditorDefinition", EditorDefinitionDescriptionMetadata.a);
    };
    EditorDefinitionDescriptionMetadata.$t = markType(EditorDefinitionDescriptionMetadata, 'EditorDefinitionDescriptionMetadata');
    EditorDefinitionDescriptionMetadata.a = null;
    return EditorDefinitionDescriptionMetadata;
}(Base));
export { EditorDefinitionDescriptionMetadata };
